Priorities.

- [X] mark a single task as _medium_ priority
- [X] mark a single task **high** priority
- [X] mark a block of tasks via the header
- [X] sort higher priority tasks to the top -- decide if within files
      only or entire project
- [X] filter output to a subset of priorities
- [X] summarise priorities?
